package VMOMI::ClusterDasVmSettingsRestartPriority;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
